==> uppy__image-editor-3.2.0.jar: META-INF/resources/webjars/uppy__image-editor/3.2.0/CHANGELOG.md <==
# @uppy/image-editor

## 3.2.0

Released: 2024-10-31
Included in: Uppy v4.6.0

- @uppy/image-editor: upgrade cropperjs (Merlijn Vos / #5497)
- @uppy/aws-s3,@uppy/box,@uppy/companion-client,@uppy/core,@uppy/dashboard,@uppy/drag-drop,@uppy/dropbox,@uppy/facebook,@uppy/file-input,@uppy/form,@uppy/golden-retriever,@uppy/google-drive,@uppy/google-photos,@uppy/image-editor,@uppy/informer,@uppy/instagram,@uppy/locales,@uppy/onedrive,@uppy/progress-bar,@uppy/provider-views,@uppy/react-native,@uppy/react,@uppy/redux-dev-tools,@uppy/screen-capture,@uppy/status-bar,@uppy/store-default,@uppy/store-redux,@uppy/svelte,@uppy/thumbnail-generator,@uppy/transloadit,@uppy/tus,@uppy/unsplash,@uppy/url,@uppy/utils,@uppy/vue,@uppy/webcam,@uppy/xhr-upload,@uppy/zoom: Fix links (Anthony Veaudry / #5492)

## 3.1.0

Released: 2024-08-29
Included in: Uppy v4.3.0

- @uppy/aws-s3,@uppy/box,@uppy/compressor,@uppy/dropbox,@uppy/facebook,@uppy/google-drive,@uppy/google-photos,@uppy/image-editor,@uppy/informer,@uppy/instagram,@uppy/onedrive,@uppy/screen-capture,@uppy/tus,@uppy/unsplash,@uppy/url,@uppy/xhr-upload,@uppy/zoom: export plugin options (Antoine du Hamel / #5433)

## 3.0.0-beta.2

Released: 2024-04-29
Included in: Uppy v4.0.0-beta.4

- @uppy/image-editor: fix label definitions (Antoine du Hamel / #5111)

## 2.4.6

Released: 2024-05-14
Included in: Uppy v3.25.3

- @uppy/image-editor: fix tooltips (Avneet Singh Malhotra / #5156)
- @uppy/image-editor: Remove `target` option from examples and document consistently (Merlijn Vos / #5146)

## 2.4.5

Released: 2024-04-29
Included in: Uppy v3.25.0

- @uppy/image-editor: fix label definitions (Antoine du Hamel / #5111)

## 2.4.4

Released: 2024-02-28
Included in: Uppy v3.23.0

- @uppy/image-editor: remove default target (Merlijn Vos / #4966)

## 2.4.1

Released: 2024-02-19
Included in: Uppy v3.22.0

- @uppy/image-editor: image editor: make compressor work after the image editor, too (evgenia karunus / #4918)
- @uppy/image-editor: migrate to ts (merlijn vos / #4880)

## 2.4.0

Released: 2023-12-12
Included in: Uppy v3.21.0

- @uppy/image-editor: respect `cropperOptions.initialAspectRatio` (Lucklj521 / #4805)

## 2.3.0

Released: 2023-11-08
Included in: Uppy v3.19.0

- @uppy/image-editor: More image editor improvements (Evgenia Karunus / #4676)

## 2.2.1

Released: 2023-09-29
Included in: Uppy v3.17.0

- @uppy/image-editor: ImageEditor.jsx - remove 1px black lines (Evgenia Karunus / #4678)

## 2.2.0

Released: 2023-09-18
Included in: Uppy v3.16.0

- @uppy/image-editor: Improve image rotation (Evgenia Karunus / #4639)

## 2.1.1

Released: 2023-03-07
Included in: Uppy v3.6.0

- @uppy/image-editor: Fix TypeScript error in image-editor types (Matthias Kunnen / #4334)

## 2.1.0

Released: 2022-11-10
Included in: Uppy v3.3.0

- @uppy/image-editor: add checkered background (Livia Medeiros / #4194)

## 2.0.1

Released: 2022-09-25
Included in: Uppy v3.1.0

- @uppy/image-editor: image-editor: fix controls in small Dashboard (Livia Medeiros / #4113)
- @uppy/audio,@uppy/aws-s3-multipart,@uppy/aws-s3,@uppy/box,@uppy/companion-client,@uppy/companion,@uppy/compressor,@uppy/core,@uppy/dashboard,@uppy/drag-drop,@uppy/drop-target,@uppy/dropbox,@uppy/facebook,@uppy/file-input,@uppy/form,@uppy/golden-retriever,@uppy/google-drive,@uppy/image-editor,@uppy/informer,@uppy/instagram,@uppy/locales,@uppy/onedrive,@uppy/progress-bar,@uppy/provider-views,@uppy/react,@uppy/redux-dev-tools,@uppy/remote-sources,@uppy/screen-capture,@uppy/status-bar,@uppy/store-default,@uppy/store-redux,@uppy/svelte,@uppy/thumbnail-generator,@uppy/transloadit,@uppy/tus,@uppy/unsplash,@uppy/url,@uppy/utils,@uppy/vue,@uppy/webcam,@uppy/xhr-upload,@uppy/zoom: add missing entries to changelog for individual packages (Antoine du Hamel / #4092)

## 2.0.0

Released: 2022-08-22
Included in: Uppy v3.0.0

- Switch to ESM

## 1.4.1

Released: 2022-07-27
Included in: Uppy v2.13.1

- @uppy/dashboard,@uppy/image-editor,@uppy/remote-sources: Fix `uppy.close()` crashes when remote-sources or image-editor is installed (Merlijn Vos / #3914)

## 1.4.0

Released: 2022-07-18
Included in: Uppy v2.13.0

- @uppy/image-editor: remove beta notice (Merlijn Vos / #3877)
- @uppy/image-editor: Add image editor cancel event (James R T / #3875)

## 1.3.0

Released: 2022-05-30
Included in: Uppy v2.11.0

- @uppy/angular,@uppy/audio,@uppy/aws-s3-multipart,@uppy/aws-s3,@uppy/box,@uppy/core,@uppy/dashboard,@uppy/drag-drop,@uppy/dropbox,@uppy/facebook,@uppy/file-input,@uppy/form,@uppy/golden-retriever,@uppy/google-drive,@uppy/image-editor,@uppy/informer,@uppy/instagram,@uppy/onedrive,@uppy/progress-bar,@uppy/react,@uppy/redux-dev-tools,@uppy/robodog,@uppy/screen-capture,@uppy/status-bar,@uppy/store-default,@uppy/store-redux,@uppy/thumbnail-generator,@uppy/transloadit,@uppy/tus,@uppy/unsplash,@uppy/url,@uppy/vue,@uppy/webcam,@uppy/xhr-upload,@uppy/zoom: doc: update bundler recommendation (Antoine du Hamel / #3763)
- @uppy/image-editor: remove CJS-interop hack in the source code (Antoine du Hamel / #3778)

## 1.2.0

Released: 2022-05-14
Included in: Uppy v2.10.0

- @uppy/image-editor: refactor to ESM (Antoine du Hamel / #3685)

## 1.1.1

Released: 2022-01-10
Included in: Uppy v2.4.0

- @uppy/image-editor: namespace input range css (Merlijn Vos / #3406)

## 1.1.0

Released: 2021-12-07
Included in: Uppy v2.3.0

- @uppy/image-editor: Pass croppedCanvasOptions to getCroppedCanvas (Mohamed Boudra / #3320)
- @uppy/aws-s3,@uppy/box,@uppy/core,@uppy/dashboard,@uppy/drag-drop,@uppy/dropbox,@uppy/facebook,@uppy/file-input,@uppy/google-drive,@uppy/image-editor,@uppy/instagram,@uppy/locales,@uppy/onedrive,@uppy/screen-capture,@uppy/status-bar,@uppy/thumbnail-generator,@uppy/transloadit,@uppy/url,@uppy/webcam,@uppy/xhr-upload,@uppy/zoom: Refactor locale scripts & generate types and docs (Merlijn Vos / #3276)

==> uppy__image-editor-3.3.3.jar: META-INF/resources/webjars/uppy__image-editor/3.3.3/CHANGELOG.md <==
# @uppy/image-editor

## 3.3.3

Released: 2025-05-18
Included in: Uppy v4.16.0

- @uppy/audio,@uppy/box,@uppy/core,@uppy/dashboard,@uppy/drag-drop,@uppy/dropbox,@uppy/facebook,@uppy/file-input,@uppy/google-drive-picker,@uppy/google-drive,@uppy/google-photos-picker,@uppy/image-editor,@uppy/instagram,@uppy/onedrive,@uppy/remote-sources,@uppy/screen-capture,@uppy/unsplash,@uppy/url,@uppy/utils,@uppy/webcam,@uppy/webdav,@uppy/zoom: ts: make locale strings optional (Merlijn Vos / #5728)

## 3.3.0

Released: 2025-01-06
Included in: Uppy v4.11.0

- @uppy/angular,@uppy/audio,@uppy/aws-s3,@uppy/box,@uppy/companion-client,@uppy/compressor,@uppy/core,@uppy/dashboard,@uppy/drag-drop,@uppy/drop-target,@uppy/dropbox,@uppy/facebook,@uppy/file-input,@uppy/form,@uppy/golden-retriever,@uppy/google-drive-picker,@uppy/google-drive,@uppy/google-photos-picker,@uppy/google-photos,@uppy/image-editor,@uppy/informer,@uppy/instagram,@uppy/locales,@uppy/onedrive,@uppy/progress-bar,@uppy/provider-views,@uppy/react,@uppy/remote-sources,@uppy/screen-capture,@uppy/status-bar,@uppy/thumbnail-generator,@uppy/transloadit,@uppy/tus,@uppy/unsplash,@uppy/url,@uppy/vue,@uppy/webcam,@uppy/webdav,@uppy/xhr-upload,@uppy/zoom: Remove "paths" from all tsconfig's (Merlijn Vos / #5572)

## 3.2.1

Released: 2024-12-05
Included in: Uppy v4.8.0

- @uppy/audio,@uppy/aws-s3,@uppy/box,@uppy/companion-client,@uppy/compressor,@uppy/core,@uppy/dashboard,@uppy/drag-drop,@uppy/drop-target,@uppy/dropbox,@uppy/facebook,@uppy/file-input,@uppy/form,@uppy/golden-retriever,@uppy/google-drive,@uppy/google-photos,@uppy/image-editor,@uppy/informer,@uppy/instagram,@uppy/locales,@uppy/onedrive,@uppy/progress-bar,@uppy/provider-views,@uppy/react,@uppy/remote-sources,@uppy/screen-capture,@uppy/status-bar,@uppy/store-default,@uppy/thumbnail-generator,@uppy/transloadit,@uppy/tus,@uppy/unsplash,@uppy/url,@uppy/utils,@uppy/vue,@uppy/webcam,@uppy/xhr-upload,@uppy/zoom: cleanup tsconfig (Mikael Finstad / #5520)

## 3.2.0

Released: 2024-10-31
Included in: Uppy v4.6.0

- @uppy/image-editor: upgrade cropperjs (Merlijn Vos / #5497)
- @uppy/aws-s3,@uppy/box,@uppy/companion-client,@uppy/core,@uppy/dashboard,@uppy/drag-drop,@uppy/dropbox,@uppy/facebook,@uppy/file-input,@uppy/form,@uppy/golden-retriever,@uppy/google-drive,@uppy/google-photos,@uppy/image-editor,@uppy/informer,@uppy/instagram,@uppy/locales,@uppy/onedrive,@uppy/progress-bar,@uppy/provider-views,@uppy/react-native,@uppy/react,@uppy/redux-dev-tools,@uppy/screen-capture,@uppy/status-bar,@uppy/store-default,@uppy/store-redux,@uppy/svelte,@uppy/thumbnail-generator,@uppy/transloadit,@uppy/tus,@uppy/unsplash,@uppy/url,@uppy/utils,@uppy/vue,@uppy/webcam,@uppy/xhr-upload,@uppy/zoom: Fix links (Anthony Veaudry / #5492)

## 3.1.0

Released: 2024-08-29
Included in: Uppy v4.3.0

- @uppy/aws-s3,@uppy/box,@uppy/compressor,@uppy/dropbox,@uppy/facebook,@uppy/google-drive,@uppy/google-photos,@uppy/image-editor,@uppy/informer,@uppy/instagram,@uppy/onedrive,@uppy/screen-capture,@uppy/tus,@uppy/unsplash,@uppy/url,@uppy/xhr-upload,@uppy/zoom: export plugin options (Antoine du Hamel / #5433)

## 3.0.0-beta.2

Released: 2024-04-29
Included in: Uppy v4.0.0-beta.4

- @uppy/image-editor: fix label definitions (Antoine du Hamel / #5111)

## 2.4.6

Released: 2024-05-14
Included in: Uppy v3.25.3

- @uppy/image-editor: fix tooltips (Avneet Singh Malhotra / #5156)
- @uppy/image-editor: Remove `target` option from examples and document consistently (Merlijn Vos / #5146)

## 2.4.5

Released: 2024-04-29
Included in: Uppy v3.25.0

- @uppy/image-editor: fix label definitions (Antoine du Hamel / #5111)

## 2.4.4

Released: 2024-02-28
Included in: Uppy v3.23.0

- @uppy/image-editor: remove default target (Merlijn Vos / #4966)

## 2.4.1

Released: 2024-02-19
Included in: Uppy v3.22.0

- @uppy/image-editor: image editor: make compressor work after the image editor, too (evgenia karunus / #4918)
- @uppy/image-editor: migrate to ts (merlijn vos / #4880)

## 2.4.0

Released: 2023-12-12
Included in: Uppy v3.21.0

- @uppy/image-editor: respect `cropperOptions.initialAspectRatio` (Lucklj521 / #4805)

## 2.3.0

Released: 2023-11-08
Included in: Uppy v3.19.0

- @uppy/image-editor: More image editor improvements (Evgenia Karunus / #4676)

## 2.2.1

Released: 2023-09-29
Included in: Uppy v3.17.0

- @uppy/image-editor: ImageEditor.jsx - remove 1px black lines (Evgenia Karunus / #4678)

## 2.2.0

Released: 2023-09-18
Included in: Uppy v3.16.0

- @uppy/image-editor: Improve image rotation (Evgenia Karunus / #4639)

## 2.1.1

Released: 2023-03-07
Included in: Uppy v3.6.0

- @uppy/image-editor: Fix TypeScript error in image-editor types (Matthias Kunnen / #4334)

## 2.1.0

Released: 2022-11-10
Included in: Uppy v3.3.0

- @uppy/image-editor: add checkered background (Livia Medeiros / #4194)

## 2.0.1

Released: 2022-09-25
Included in: Uppy v3.1.0

- @uppy/image-editor: image-editor: fix controls in small Dashboard (Livia Medeiros / #4113)
- @uppy/audio,@uppy/aws-s3-multipart,@uppy/aws-s3,@uppy/box,@uppy/companion-client,@uppy/companion,@uppy/compressor,@uppy/core,@uppy/dashboard,@uppy/drag-drop,@uppy/drop-target,@uppy/dropbox,@uppy/facebook,@uppy/file-input,@uppy/form,@uppy/golden-retriever,@uppy/google-drive,@uppy/image-editor,@uppy/informer,@uppy/instagram,@uppy/locales,@uppy/onedrive,@uppy/progress-bar,@uppy/provider-views,@uppy/react,@uppy/redux-dev-tools,@uppy/remote-sources,@uppy/screen-capture,@uppy/status-bar,@uppy/store-default,@uppy/store-redux,@uppy/svelte,@uppy/thumbnail-generator,@uppy/transloadit,@uppy/tus,@uppy/unsplash,@uppy/url,@uppy/utils,@uppy/vue,@uppy/webcam,@uppy/xhr-upload,@uppy/zoom: add missing entries to changelog for individual packages (Antoine du Hamel / #4092)

## 2.0.0

Released: 2022-08-22
Included in: Uppy v3.0.0

- Switch to ESM

## 1.4.1

Released: 2022-07-27
Included in: Uppy v2.13.1

- @uppy/dashboard,@uppy/image-editor,@uppy/remote-sources: Fix `uppy.close()` crashes when remote-sources or image-editor is installed (Merlijn Vos / #3914)

## 1.4.0

Released: 2022-07-18
Included in: Uppy v2.13.0

- @uppy/image-editor: remove beta notice (Merlijn Vos / #3877)
- @uppy/image-editor: Add image editor cancel event (James R T / #3875)

## 1.3.0

Released: 2022-05-30
Included in: Uppy v2.11.0

- @uppy/angular,@uppy/audio,@uppy/aws-s3-multipart,@uppy/aws-s3,@uppy/box,@uppy/core,@uppy/dashboard,@uppy/drag-drop,@uppy/dropbox,@uppy/facebook,@uppy/file-input,@uppy/form,@uppy/golden-retriever,@uppy/google-drive,@uppy/image-editor,@uppy/informer,@uppy/instagram,@uppy/onedrive,@uppy/progress-bar,@uppy/react,@uppy/redux-dev-tools,@uppy/robodog,@uppy/screen-capture,@uppy/status-bar,@uppy/store-default,@uppy/store-redux,@uppy/thumbnail-generator,@uppy/transloadit,@uppy/tus,@uppy/unsplash,@uppy/url,@uppy/vue,@uppy/webcam,@uppy/xhr-upload,@uppy/zoom: doc: update bundler recommendation (Antoine du Hamel / #3763)
- @uppy/image-editor: remove CJS-interop hack in the source code (Antoine du Hamel / #3778)

## 1.2.0

Released: 2022-05-14
Included in: Uppy v2.10.0

- @uppy/image-editor: refactor to ESM (Antoine du Hamel / #3685)

## 1.1.1

Released: 2022-01-10
Included in: Uppy v2.4.0

- @uppy/image-editor: namespace input range css (Merlijn Vos / #3406)

## 1.1.0

Released: 2021-12-07
Included in: Uppy v2.3.0

- @uppy/image-editor: Pass croppedCanvasOptions to getCroppedCanvas (Mohamed Boudra / #3320)
- @uppy/aws-s3,@uppy/box,@uppy/core,@uppy/dashboard,@uppy/drag-drop,@uppy/dropbox,@uppy/facebook,@uppy/file-input,@uppy/google-drive,@uppy/image-editor,@uppy/instagram,@uppy/locales,@uppy/onedrive,@uppy/screen-capture,@uppy/status-bar,@uppy/thumbnail-generator,@uppy/transloadit,@uppy/url,@uppy/webcam,@uppy/xhr-upload,@uppy/zoom: Refactor locale scripts & generate types and docs (Merlijn Vos / #3276)
